#[repr(C)]pub struct DeviceGetMaxTransferSizeResponse {
pub size: Uint64,
}Expand description
The wire type corresponding to DeviceGetMaxTransferSizeResponse.
Fields
size: Uint64Trait Implementations
Sourceimpl Clone for DeviceGetMaxTransferSizeResponse
impl Clone for DeviceGetMaxTransferSizeResponse
Sourcefn clone(&self) -> DeviceGetMaxTransferSizeResponse
fn clone(&self) -> DeviceGetMaxTransferSizeResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetMaxTransferSizeResponse
impl Constrained for DeviceGetMaxTransferSizeResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, DeviceGetMaxTransferSizeResponse>,
_: <DeviceGetMaxTransferSizeResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, DeviceGetMaxTransferSizeResponse>, _: <DeviceGetMaxTransferSizeResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl<___D> Decode<___D> for DeviceGetMaxTransferSizeResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetMaxTransferSizeResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetMaxTransferSizeResponse, ___E> for &'a DeviceGetMaxTransferSizeResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetMaxTransferSizeResponse, ___E> for &'a DeviceGetMaxTransferSizeResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetMaxTransferSizeResponse, ___E> for DeviceGetMaxTransferSizeResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetMaxTransferSizeResponse, ___E> for DeviceGetMaxTransferSizeResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetMaxTransferSizeResponse, DeviceGetMaxTransferSizeResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetMaxTransferSizeResponse, DeviceGetMaxTransferSizeResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetMaxTransferSizeResponse, ___E> for DeviceGetMaxTransferSizeResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
impl<___E, T0> Encode<DeviceGetMaxTransferSizeResponse, ___E> for DeviceGetMaxTransferSizeResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Uint64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetMaxTransferSizeResponse> for DeviceGetMaxTransferSizeResponse
impl FromWire<DeviceGetMaxTransferSizeResponse> for DeviceGetMaxTransferSizeResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetMaxTransferSizeResponse, DeviceGetMaxTransferSizeResponse>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetMaxTransferSizeResponse, DeviceGetMaxTransferSizeResponse>
Sourcefn from_wire(
wire: DeviceGetMaxTransferSizeResponse,
) -> DeviceGetMaxTransferSizeResponse
fn from_wire( wire: DeviceGetMaxTransferSizeResponse, ) -> DeviceGetMaxTransferSizeResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetMaxTransferSizeResponse> for DeviceGetMaxTransferSizeResponse
impl FromWireRef<DeviceGetMaxTransferSizeResponse> for DeviceGetMaxTransferSizeResponse
Sourcefn from_wire_ref(
wire: &DeviceGetMaxTransferSizeResponse,
) -> DeviceGetMaxTransferSizeResponse
fn from_wire_ref( wire: &DeviceGetMaxTransferSizeResponse, ) -> DeviceGetMaxTransferSizeResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetMaxTransferSizeResponse
impl IntoNatural for DeviceGetMaxTransferSizeResponse
Sourcetype Natural = DeviceGetMaxTransferSizeResponse
type Natural = DeviceGetMaxTransferSizeResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetMaxTransferSizeResponse
impl Wire for DeviceGetMaxTransferSizeResponse
Sourcetype Narrowed<'de> = DeviceGetMaxTransferSizeResponse
type Narrowed<'de> = DeviceGetMaxTransferSizeResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>)
fn zero_padding(out_: &mut MaybeUninit<DeviceGetMaxTransferSizeResponse>)
Writes zeroes to the padding for this type, if any.